# if you add a new CDE to the density_estimation_methods subpackage, also import
# it here 
from cfl.density_estimation_methods.condExpCNN import CondExpCNN
from cfl.density_estimation_methods.condExpCNN3D import CondExpCNN3D
from cfl.density_estimation_methods.condExpKC import CondExpKC
from cfl.density_estimation_methods.condExpMod import CondExpMod
from cfl.density_estimation_methods.condExpVB import CondExpVB 
from cfl.density_estimation_methods.CDE import CDE
